@@ -1,11 +1,13 @@
 ## ---- include = FALSE---------------------------------------------------------
-knitr::opts_chunk$set(
-  error = TRUE,
-  collapse = TRUE,
-  #eval = FALSE, echo = FALSE,
-  comment = "#>"
-)
+# To suppress messages
+library(tibble)
+library(vctrs)
 
+knitr::opts_chunk$set(
+  collapse = TRUE,
+  comment = "#>",
+  error = TRUE
+)
 tibble:::set_dftbl_hooks()
 
 options(
@@ -16,11 +18,11 @@ options(
 )
 
 # Set to FALSE for production
-if (!exists("eval_details")) eval_details <- FALSE
+eval_details <- (Sys.getenv("IN_GALLEY") != "")
 
 ## ----setup--------------------------------------------------------------------
 library(tibble)
-suppressWarnings(library(vctrs))
+library(vctrs)
 
 new_df <- function() {
   df <- data.frame(n = c(1L, NA, 3L, NA))
@@ -561,6 +563,10 @@ with_tbl2(tbl2[2:3, 2] <- tbl[1:2, 1])
 ## ----bracket-i-j-na-init, dftbl = TRUE----------------------------------------
 
 with_tbl({tbl$x <- NA; tbl[2:3, "x"] <- 3:2})
+with_df({df[2:3, 2:3] <- NA})
+with_tbl({tbl[2:3, 2:3] <- NA})
+
+## ----bracket-i-j-typed-na-init, dftbl = TRUE----------------------------------
 
 with_tbl({tbl$x <- NA_integer_; tbl[2:3, "x"] <- 3:2})
 
