@@ -77,7 +77,7 @@ test_that("empty input makes 0 x 0 tbl_df", {
 
 test_that("SE version", {
   scoped_lifecycle_silence()
-  expect_identical(tibble_(list(a = ~1:10)), tibble(a = 1:10))
+  expect_identical(tibble_(list(a = ~ 1:10)), tibble(a = 1:10))
 })
 
 test_that("names are stripped from vectors", {
@@ -132,7 +132,7 @@ test_that("columns are recycled to common length", {
 test_that("columns must be same length", {
   expect_legacy_error(
     as_tibble(list(x = 1:2, y = 1:3)),
-    error_inconsistent_cols(NULL,  c("x", "y"), 2:3, NA),
+    error_inconsistent_cols(NULL, c("x", "y"), 2:3, NA),
     fixed = TRUE
   )
   expect_legacy_error(
@@ -205,7 +205,7 @@ test_that("as_tibble.tbl_df() leaves classes unchanged (#60)", {
 
 
 test_that("Can convert tables to data frame", {
-  mtcars_table <- xtabs(mtcars, formula = ~vs + am + cyl)
+  mtcars_table <- xtabs(mtcars, formula = ~ vs + am + cyl)
 
   mtcars2 <- as_tibble(mtcars_table)
   expect_equal(names(mtcars2), c(names(dimnames(mtcars_table)), "n"))
@@ -270,28 +270,28 @@ test_that("as_tibble() checks for `unique` names by default (#278)", {
   l1 <- list(1:10)
   expect_legacy_error(
     as_tibble(l1),
-    error_column_must_be_named(1, repair = TRUE),
+    error_column_must_be_named(1, repair_hint = TRUE),
     fixed = TRUE
   )
 
   l2 <- list(x = 1, 2)
   expect_legacy_error(
     as_tibble(l2),
-    error_column_must_be_named(2, repair = TRUE),
+    error_column_must_be_named(2, repair_hint = TRUE),
     fixed = TRUE
   )
 
   l3 <- list(x = 1, ... = 2)
   expect_legacy_error(
     as_tibble(l3),
-    error_column_must_not_be_dot_dot(2, repair = TRUE),
+    error_column_must_not_be_dot_dot(2, repair_hint = TRUE),
     fixed = TRUE
   )
 
   l4 <- list(x = 1, ..1 = 2)
   expect_legacy_error(
     as_tibble(l4),
-    error_column_must_not_be_dot_dot(2, repair = TRUE),
+    error_column_must_not_be_dot_dot(2, repair_hint = TRUE),
     fixed = TRUE
   )
 
@@ -300,7 +300,7 @@ test_that("as_tibble() checks for `unique` names by default (#278)", {
   df <- new_tibble(df, nrow = 1)
   expect_legacy_error(
     as_tibble(df),
-    error_column_must_be_named(1:2, repair = TRUE),
+    error_column_must_be_named(1:2, repair_hint = TRUE),
     fixed = TRUE
   )
 })
@@ -342,7 +342,7 @@ test_that("as_tibble() implements custom name repair", {
 
   invalid_df_purrr <- as_tibble(
     list(3, 4, 5),
-    .name_repair = ~make.names(., unique = TRUE)
+    .name_repair = ~ make.names(., unique = TRUE)
   )
   expect_identical(invalid_df_purrr, invalid_df)
 })
@@ -612,7 +612,7 @@ test_that("`validate` triggers deprecation message, but then works", {
       "deprecated",
       fixed = TRUE
     ),
-    error_column_must_be_named(2, repair = TRUE)
+    error_column_must_be_named(2, repair_hint = TRUE)
   )
 
   expect_warning(
@@ -639,7 +639,7 @@ test_that("`validate` triggers deprecation message, but then works", {
       "deprecated",
       fixed = TRUE
     ),
-    error_column_must_be_named(2, repair = TRUE)
+    error_column_must_be_named(2, repair_hint = TRUE)
   )
 })
 
@@ -653,7 +653,7 @@ test_that("Consistent `validate` and `.name_repair` used together keep silent.",
       as_tibble(list(a = 1, "hi"), validate = TRUE, .name_repair = "check_unique"),
       NA
     ),
-    error_column_must_be_named(2, repair = TRUE)
+    error_column_must_be_named(2, repair_hint = TRUE)
   )
 
   expect_warning(
@@ -677,7 +677,7 @@ test_that("Consistent `validate` and `.name_repair` used together keep silent.",
       as_tibble(df, validate = TRUE, .name_repair = "check_unique"),
       NA
     ),
-    error_column_must_be_named(2, repair = TRUE)
+    error_column_must_be_named(2, repair_hint = TRUE)
   )
 })
 
@@ -689,7 +689,7 @@ test_that("Inconsistent `validate` and `.name_repair` used together raise a warn
       as_tibble(list(a = 1, "hi"), validate = FALSE, .name_repair = "check_unique"),
       "precedence"
     ),
-    error_column_must_be_named(2, repair = TRUE)
+    error_column_must_be_named(2, repair_hint = TRUE)
   )
 
   expect_warning(
@@ -713,7 +713,7 @@ test_that("Inconsistent `validate` and `.name_repair` used together raise a warn
       as_tibble(df, validate = FALSE, .name_repair = "check_unique"),
       "precedence"
     ),
-    error_column_must_be_named(2, repair = TRUE)
+    error_column_must_be_named(2, repair_hint = TRUE)
   )
 })
 
